@@ -88,12 +88,12 @@ ConfigPtr Fake::config() const
     return mConfig;
 }
 
-std::expected<void, QString> Fake::setConfig(const ConfigPtr &config)
+QFuture<SetConfigResult> Fake::setConfig(const ConfigPtr &config)
 {
     qCDebug(KSCREEN_FAKE) << "set config" << config->outputs();
     mConfig = config->clone();
     Q_EMIT configChanged(mConfig);
-    return {};
+    return QtFuture::makeReadyFuture<SetConfigResult>(SetConfigResult());
 }
 
 bool Fake::isValid() const
@@ -145,17 +145,6 @@ void Fake::setEnabled(int outputId, bool enabled)
     Q_EMIT configChanged(mConfig);
 }
 
-void Fake::setPrimary(int outputId, bool primary)
-{
-    KScreen::OutputPtr output = config()->output(outputId);
-    if (!output || output->isPrimary() == primary) {
-        return;
-    }
-
-    mConfig->setPrimaryOutput(output);
-    Q_EMIT configChanged(mConfig);
-}
-
 void Fake::setCurrentModeId(int outputId, const QString &modeId)
 {
     KScreen::OutputPtr output = config()->output(outputId);
