@@ -222,8 +222,22 @@ void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output, const QMap<int,
     });
     output->setEdrPolicy(static_cast<Output::EdrPolicy>(m_edrPolicy));
     output->setSharpness(m_sharpness / 10'000.0);
+    output->setAutomaticBrightness(m_autoBrightness);
 
     updateKScreenModes(output);
+
+    m_customModes.clear();
+    for (const auto &mode : m_modes) {
+        if (!(mode->flags() & ModeInfo::Flag::Custom)) {
+            continue;
+        }
+        m_customModes.push_back(ModeInfo{
+            .size = mode->size(),
+            .refreshRate = mode->refreshRate(),
+            .flags = mode->flags(),
+        });
+    }
+    output->setCustomModes(m_customModes);
 }
 
 QString WaylandOutputDevice::modeId() const
@@ -241,7 +255,10 @@ WaylandOutputDeviceMode *WaylandOutputDevice::deviceModeFromId(const QString &id
     return nullptr;
 }
 
-bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, const KScreen::OutputPtr &output, const QMap<int, WaylandOutputDevice *> &outputMap)
+bool WaylandOutputDevice::setWlConfig(WaylandOutputManagement *management,
+                                      WaylandOutputConfiguration *wlConfig,
+                                      const KScreen::OutputPtr &output,
+                                      const QMap<int, WaylandOutputDevice *> &outputMap)
 {
     bool changed = false;
 
@@ -375,6 +392,23 @@ bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, cons
         wlConfig->set_sharpness(object(), std::round(output->sharpness() * 10'000));
         changed = true;
     }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_CUSTOM_MODES_SINCE_VERSION && m_customModes != output->customModes()) {
+        auto list = management->create_mode_list();
+        const auto modes = output->customModes();
+        for (const auto &mode : modes) {
+            kde_mode_list_v2_set_resolution(list, mode.size.width(), mode.size.height());
+            kde_mode_list_v2_set_refresh_rate(list, std::round(mode.refreshRate * 1000));
+            kde_mode_list_v2_set_reduced_blanking(list, mode.flags & ModeInfo::Flag::ReducedBlanking ? 1 : 0);
+            kde_mode_list_v2_add_mode(list);
+        }
+        wlConfig->set_custom_modes(object(), list);
+        kde_mode_list_v2_destroy(list);
+        changed = true;
+    }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_AUTO_BRIGHTNESS_SINCE_VERSION && m_autoBrightness != output->automaticBrightness()) {
+        wlConfig->set_auto_brightness(object(), output->automaticBrightness() ? 1 : 0);
+        changed = true;
+    }
 
     return changed;
 }
@@ -396,11 +430,6 @@ QDebug operator<<(QDebug dbg, const WaylandOutputDevice *output)
     return dbg;
 }
 
-void WaylandOutputDevice::setIndex(uint32_t index)
-{
-    m_index = index;
-}
-
 uint32_t WaylandOutputDevice::index() const
 {
     return m_index;
@@ -581,6 +610,16 @@ void WaylandOutputDevice::kde_output_device_v2_sharpness(uint32_t sharpness)
     m_sharpness = sharpness;
 }
 
+void WaylandOutputDevice::kde_output_device_v2_priority(uint32_t priority)
+{
+    m_index = priority;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_auto_brightness(uint32_t enabled)
+{
+    m_autoBrightness = enabled;
+}
+
 QByteArray WaylandOutputDevice::edid() const
 {
     return m_edid;
