@@ -19,6 +19,7 @@
 namespace KScreen
 {
 class WaylandOutputConfiguration;
+class WaylandOutputManagement;
 
 class WaylandOutputDevice : public QObject, public QtWayland::kde_output_device_v2
 {
@@ -48,9 +49,11 @@ public:
     void updateKScreenOutput(OutputPtr &output, const QMap<int, WaylandOutputDevice *> &outputMap);
     void updateKScreenModes(OutputPtr &output);
 
-    void setIndex(uint32_t priority);
     uint32_t index() const;
-    bool setWlConfig(WaylandOutputConfiguration *wlConfig, const KScreen::OutputPtr &output, const QMap<int, WaylandOutputDevice *> &outputMap);
+    bool setWlConfig(WaylandOutputManagement *management,
+                     WaylandOutputConfiguration *wlConfig,
+                     const KScreen::OutputPtr &output,
+                     const QMap<int, WaylandOutputDevice *> &outputMap);
 
     QString modeId() const;
     QString uuid() const
@@ -103,6 +106,8 @@ protected:
     void kde_output_device_v2_automatic_max_bits_per_color_limit(uint32_t max_bpc_limit) override;
     void kde_output_device_v2_edr_policy(uint32_t policy) override;
     void kde_output_device_v2_sharpness(uint32_t sharpness) override;
+    void kde_output_device_v2_priority(uint32_t priority) override;
+    void kde_output_device_v2_auto_brightness(uint32_t enabled) override;
 
 private:
     QString modeName(const WaylandOutputDeviceMode *m) const;
@@ -156,6 +161,8 @@ private:
     } bpcRange;
     uint32_t m_edrPolicy = edr_policy_always;
     uint32_t m_sharpness = 0;
+    QList<ModeInfo> m_customModes;
+    bool m_autoBrightness = false;
 };
 
 }
