@@ -5,6 +5,7 @@
  */
 #pragma once
 
+#include "output.h"
 #include "qwayland-kde-output-device-v2.h"
 
 #include <QObject>
@@ -25,6 +26,7 @@ public:
     float refreshRate() const;
     QSize size() const;
     bool preferred() const;
+    ModeInfo::Flags flags() const;
 
     static WaylandOutputDeviceMode *get(struct ::kde_output_device_mode_v2 *object);
 
@@ -36,12 +38,14 @@ protected:
     void kde_output_device_mode_v2_refresh(int32_t refresh) override;
     void kde_output_device_mode_v2_preferred() override;
     void kde_output_device_mode_v2_removed() override;
+    void kde_output_device_mode_v2_flags(uint32_t flags) override;
 
 private:
     QString m_id;
     float m_refreshRate = 60.0;
     QSize m_size;
     bool m_preferred = false;
+    ModeInfo::Flags m_flags;
 };
 
 }
